summaryrefslogtreecommitdiff
path: root/FS/FS/Upgrade.pm
diff options
context:
space:
mode:
authorMark Wells <mark@freeside.biz>2015-05-30 15:12:07 -0700
committerMark Wells <mark@freeside.biz>2015-05-30 15:12:07 -0700
commit817c1ce0e1cbcfd1f684222c66f46dd13b2d6dd7 (patch)
tree25fd80fae19bbe1b4ec2c892a35a631cf232d590 /FS/FS/Upgrade.pm
parent3846acae1c2a7ecb275e400cf3802ada6bc89ed2 (diff)
SureTax, #31639, #33015, #34598
Diffstat (limited to 'FS/FS/Upgrade.pm')
-rw-r--r--FS/FS/Upgrade.pm8
1 files changed, 4 insertions, 4 deletions
diff --git a/FS/FS/Upgrade.pm b/FS/FS/Upgrade.pm
index b4340d075..ffc04bab7 100644
--- a/FS/FS/Upgrade.pm
+++ b/FS/FS/Upgrade.pm
@@ -133,11 +133,11 @@ If you need to continue using the old Form 477 report, turn on the
$conf->set($newname, 'location');
}
- # boolean enable_taxproducts is now enable_taxproducts = 'cch'
- if ( $conf->exists('enable_taxproducts') and
- $conf->config('enable_taxproducts') eq '' ) {
+ # boolean enable_taxproducts is now tax_data_vendor = 'cch'
+ if ( $conf->exists('enable_taxproducts') ) {
- $conf->set('enable_taxproducts', 'cch');
+ $conf->delete('enable_taxproducts');
+ $conf->set('tax_data_vendor', 'cch');
}